@@ -16,7 +16,6 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- *  $Id$
  */
 
 #include "config.h" 
@@ -33,11 +32,7 @@
 
 #include <glib/gi18n.h>
 #include <gtk/gtk.h>
-#include <libgnomeui/gnome-icon-lookup.h>
 
-#ifdef HAVE_LIBCANBERRA_GTK
-#include <canberra-gtk.h>
-#endif
 
 #ifdef HAVE_LIBNOTIFY
 #include <libnotify/notify.h>
@@ -45,7 +40,7 @@
 
 enum
 {
-	COL_STATE,
+	COL_STATUS,
 	COL_PERCENT,
 	COL_IMAGE,
 	COL_FILE,
@@ -158,13 +153,13 @@ show_downloader_cb (DownloaderView *dv)
 	}
 }
 
-static gboolean
+static void
 status_icon_popup_menu_cb (GtkStatusIcon *icon,
 			   guint button,
 			   guint time,
-			   DownloaderView *dv)
+                           DownloaderView *dv)
 {
-	GtkWidget *menu, *item;
+        GtkWidget *menu, *item;
 
 	menu = gtk_menu_new ();
 
@@ -178,8 +173,6 @@ status_icon_popup_menu_cb (GtkStatusIcon *icon,
 	gtk_menu_popup (GTK_MENU (menu), NULL, NULL,
 			gtk_status_icon_position_menu, icon,
 			button, time);
-
-	return TRUE;
 }
 
 static void
@@ -195,19 +188,24 @@ show_status_icon (DownloaderView *dv)
 
 	g_signal_connect_swapped (priv->status_icon, "activate",
 				  G_CALLBACK (show_downloader_cb), dv);
-	g_signal_connect (dv->priv->status_icon, "popup-menu",
+	g_signal_connect (priv->status_icon, "popup-menu",
 			  G_CALLBACK (status_icon_popup_menu_cb), dv);
 }
 
 static gboolean
-remove_download (EphyDownload *download,
+remove_download (WebKitDownload *download,
 		 gpointer rowref,
 		 DownloaderView *view)
 {
+	WebKitDownloadStatus status;
+
 	g_signal_handlers_disconnect_matched
 		(download, G_SIGNAL_MATCH_DATA ,
 		 0, 0, NULL, NULL, view);
-	ephy_download_cancel (download);
+
+	status = webkit_download_get_status (download);
+	if (status == WEBKIT_DOWNLOAD_STATUS_STARTED)
+		webkit_download_cancel (download);
 
 	g_object_unref (download);
 	return TRUE;
@@ -305,13 +303,13 @@ downloader_view_new (void)
 }
 
 static char *
-format_interval (gint64 interval)
+format_interval (gdouble interval)
 {
 	int hours, mins, secs;
 
-	hours = (int) interval / 3600;
+	hours = (int) (interval / 3600);
 	interval -= hours * 3600;
-	mins = (int) interval / 60;
+	mins = (int) (interval / 60);
 	interval -= mins * 60;
 	secs = (int) interval;
 
@@ -326,7 +324,7 @@ format_interval (gint64 interval)
 }
 
 static GtkTreeRowReference *
-get_row_from_download (DownloaderView *dv, EphyDownload *download)
+get_row_from_download (DownloaderView *dv, WebKitDownload *download)
 {
 	return  g_hash_table_lookup (dv->priv->downloads_hash, download);
 }
@@ -337,8 +335,8 @@ update_buttons (DownloaderView *dv)
 	GtkTreeSelection *selection;
 	GtkTreeModel *model;
 	GtkTreeIter iter;
-	EphyDownloadState state;
-	EphyDownload *download;
+	WebKitDownloadStatus status;
+	WebKitDownload *download;
 	gboolean pause_enabled = FALSE;
 	gboolean abort_enabled = FALSE;
 	gboolean label_pause = TRUE;
@@ -353,23 +351,12 @@ update_buttons (DownloaderView *dv)
 			return;
 		
 		gtk_tree_model_get (model, &iter, COL_DOWNLOAD_OBJECT, &download, -1);
-		state = ephy_download_get_state (download);
+		status = webkit_download_get_status (download);
 
-		switch (state)
-		{
-		case EPHY_DOWNLOAD_DOWNLOADING:
-			pause_enabled = TRUE;
-			abort_enabled = TRUE;
-			break;
-		case EPHY_DOWNLOAD_PAUSED:
-			pause_enabled = TRUE;
-			abort_enabled = TRUE;
-			label_pause = FALSE;
-			break;
-		default:
-			abort_enabled = TRUE;
-			break;
-		}
+		/* Pausing is not supported yet */
+		pause_enabled = FALSE;
+		label_pause = TRUE;
+		abort_enabled = TRUE;
 	}
 	else
 	{
@@ -385,14 +372,58 @@ update_buttons (DownloaderView *dv)
 			      label_pause ? _("_Pause") : _("_Resume"));
 }
 
+static char *
+ephy_download_get_name (WebKitDownload *download)
+{
+	const char *target;
+	char *result;
+
+	target = webkit_download_get_destination_uri (download);
+
+	if (target)
+	{
+		result = g_path_get_basename (target);
+	}
+	else
+	{
+		result = g_strdup (_("Unknown"));
+	}
+
+	return result;
+}
+
+static gdouble
+ephy_download_get_remaining_time (WebKitDownload *download)
+{
+	gint64 total, cur;
+	gdouble elapsed_time;
+	gdouble remaining_time;
+	gdouble per_byte_time;
+
+	total = webkit_download_get_total_size (download);
+	cur = webkit_download_get_current_size (download);
+	elapsed_time = webkit_download_get_elapsed_time (download);
+
+	if (cur <= 0)
+	{
+		return -1.0;
+	}
+
+	per_byte_time = elapsed_time / cur;
+	remaining_time = per_byte_time * (total - cur);
+
+	return remaining_time;
+}
+
 static void
-update_download_row (DownloaderView *dv, EphyDownload *download)
+update_download_row (DownloaderView *dv, WebKitDownload *download)
 {
 	GtkTreeRowReference *row_ref;
 	GtkTreePath *path;
 	GtkTreeIter iter;
-	EphyDownloadState state;
-	gint64 remaining_secs = 0, total, current;
+	WebKitDownloadStatus status;
+	gint64 total, current;
+	gdouble remaining_seconds = 0.0;
 	char *remaining, *file, *cur_progress, *name;
 	struct tm;
 	int percent = 0;
@@ -404,21 +435,23 @@ update_download_row (DownloaderView *dv, EphyDownload *download)
 	row_ref = get_row_from_download (dv, download);
 	g_return_if_fail (row_ref != NULL);
 
-	/* State special casing */
-	state = ephy_download_get_state (download);
+	/* Status special casing */
+	status = webkit_download_get_status (download);
 
-	total = ephy_download_get_total_progress (download);
-	current = ephy_download_get_current_progress (download);
+	total = webkit_download_get_total_size (download);
+	current = webkit_download_get_current_size (download);
 
 	cur_progress = g_format_size_for_display (current);
 
 	name = ephy_download_get_name (download);
 	
-	switch (state)
+	switch (status)
 	{
-	case EPHY_DOWNLOAD_COMPLETED:
+	case WEBKIT_DOWNLOAD_STATUS_CANCELLED:
+		downloader_view_remove_download (dv, download);
+		return;
+	case WEBKIT_DOWNLOAD_STATUS_FINISHED:
 		downloader_view_remove_download (dv, download);
-		
 #ifdef HAVE_LIBNOTIFY
 		downloaded = g_strdup_printf (_("The file “%s” has been downloaded."), 
 						name);
@@ -431,19 +464,11 @@ update_download_row (DownloaderView *dv, EphyDownload *download)
 		
 		g_free (downloaded);
 #endif
-#ifdef HAVE_LIBCANBERRA_GTK
-	ca_context_play (ca_gtk_context_get (), 0,
-			CA_PROP_APPLICATION_NAME, _("GNOME Web Browser"),
-			CA_PROP_EVENT_ID, "complete-download",
-			CA_PROP_EVENT_DESCRIPTION, _("Download completed"),
-			NULL);
-#endif
 
 		return;
-	case EPHY_DOWNLOAD_PAUSED:
-	case EPHY_DOWNLOAD_DOWNLOADING:
-		percent = ephy_download_get_percent (download);
-		remaining_secs = ephy_download_get_remaining_time (download);
+	case WEBKIT_DOWNLOAD_STATUS_STARTED:
+		percent = (int) (webkit_download_get_progress (download) * 100);
+		remaining_seconds = ephy_download_get_remaining_time (download);
 		break;
 	default:
 		break;
@@ -468,20 +493,20 @@ update_download_row (DownloaderView *dv, EphyDownload *download)
 		file = g_strdup_printf ("%s\n%s", name, _("Unknown"));
 	}
 
-	if (remaining_secs < 0)
+	if (remaining_seconds < 0)
 	{
 		remaining = g_strdup (_("Unknown"));
 	}
 	else
 	{
-		remaining = format_interval (remaining_secs);
+		remaining = format_interval (remaining_seconds);
 	}
 
 	path = gtk_tree_row_reference_get_path (row_ref);
 	gtk_tree_model_get_iter (dv->priv->model, &iter, path);
 	gtk_list_store_set (GTK_LIST_STORE (dv->priv->model),
 			    &iter,
-			    COL_STATE, state,
+			    COL_STATUS, status,
 			    COL_PERCENT, percent,
 			    COL_FILE, file,
 			    COL_REMAINING, remaining,
@@ -503,16 +528,32 @@ update_status_icon (DownloaderView *dv)
 	downloads = g_hash_table_size (dv->priv->downloads_hash);
 
 	downloadstring = g_strdup_printf (ngettext ("%d download", 
-					"%d downloads", downloads), 
-					downloads);
+                                                    "%d downloads", downloads), 
+                                          downloads);
 
-	gtk_status_icon_set_tooltip (dv->priv->status_icon,
-				     downloadstring);
+	gtk_status_icon_set_tooltip_text (dv->priv->status_icon,
+					  downloadstring);
 	g_free (downloadstring);
 }
 
 static void
-download_changed_cb (EphyDownload *download, DownloaderView *dv)
+download_progress_cb (WebKitDownload *download, GParamSpec *pspec, DownloaderView *dv)
+{
+	update_download_row (dv, download);
+}
+
+static void
+download_status_changed_cb (WebKitDownload *download, GParamSpec *pspec, DownloaderView *dv)
+{
+        /* We already have handlers for progress and cancel/error, so
+         * we only handle finished here.
+         */
+        if (webkit_download_get_status (download) == WEBKIT_DOWNLOAD_STATUS_FINISHED)
+                update_download_row (dv, download);
+}
+
+static void
+download_error_cb (WebKitDownload *download, gint error_code, gint error_detail, const gchar *reason, DownloaderView *dv)
 {
 	update_download_row (dv, download);
 }
@@ -556,17 +597,19 @@ show_notification_window (DownloaderView *dv)
 
 void
 downloader_view_add_download (DownloaderView *dv,
-			      EphyDownload *download)
+			      WebKitDownload *download)
 {
 	GtkTreeRowReference *row_ref;
 	GtkTreeIter iter;
 	GtkTreeSelection *selection;
 	GtkTreePath *path;
+#if 0
 	GtkIconTheme *theme;
 	GtkIconInfo *icon_info;
 	GdkPixbuf *pixbuf;
 	char *mime, *icon_name;
 	int width = 16, height = 16;
+#endif
 	GValue visible = {0, };
 
 #ifdef HAVE_LIBNOTIFY
@@ -596,19 +639,27 @@ downloader_view_add_download (DownloaderView *dv,
 	gtk_tree_selection_unselect_all (selection);
 	gtk_tree_selection_select_iter (selection, &iter);
 
-	g_signal_connect_object (download, "changed",
-				 G_CALLBACK (download_changed_cb), dv, 0);
+	g_signal_connect_object (download, "notify::progress",
+				 G_CALLBACK (download_progress_cb), dv, 0);
+
+	g_signal_connect_object (download, "notify::status",
+				 G_CALLBACK (download_status_changed_cb), dv, 0);
+
+	g_signal_connect_object (download, "error",
+				 G_CALLBACK (download_error_cb), dv, 0);
 
 	/* Show it already */
 	g_value_init (&visible, G_TYPE_BOOLEAN);
-	g_object_get_property (G_OBJECT(dv->priv->window), "visible", &visible);
+	g_object_get_property (G_OBJECT (dv->priv->window), "visible", &visible);
 	
 	if (eel_gconf_get_boolean (CONF_DOWNLOADS_HIDDEN) && !g_value_get_boolean (&visible))
 	{
 
 #ifdef HAVE_LIBNOTIFY
+		char *name = ephy_download_get_name (download);
 		downloading = g_strdup_printf(_("The file “%s” has been added to the downloads queue."), 
-						ephy_download_get_name (download));
+						name);
+		g_free (name);
 		notify_notification_update (dv->priv->notification,
 					_("Download started"), 
 					downloading, 
@@ -627,7 +678,9 @@ downloader_view_add_download (DownloaderView *dv,
 	}
 	
 	g_value_unset (&visible);
-	
+
+#if 0
+        // FIXMEchpe port this to use GIcon when webkit gets download support
 	mime =  ephy_download_get_mime (download);
 
 	theme = gtk_icon_theme_get_default ();
@@ -653,7 +706,8 @@ downloader_view_add_download (DownloaderView *dv,
 	{
 		g_object_unref (pixbuf);
 	}
-	
+#endif
+
 	dv->priv->source_id = g_timeout_add (100, (GSourceFunc) update_buttons_timeout_cb, dv);
 }
 
@@ -670,34 +724,29 @@ progress_cell_data_func (GtkTreeViewColumn *col,
 			 GtkTreeIter       *iter,
 			 gpointer           user_data)
 {
-	EphyDownloadState state;
+	WebKitDownloadStatus status;
 	const char *text = NULL;
 	int percent;
 
 	gtk_tree_model_get (model, iter,
-			    COL_STATE, &state,
+			    COL_STATUS, &status,
 			    COL_PERCENT, &percent,
 			    -1);
 
-	switch (state)
+	switch (status)
 	{
-		case EPHY_DOWNLOAD_INITIALISING:
-			/* Translators: The text before the "|" is context to help you decide on
-			 * the correct translation. You MUST OMIT it in the translated string. */
-			text = Q_("download status|Unknown");
+		case WEBKIT_DOWNLOAD_STATUS_CREATED:
+			text = C_("download status", "Unknown");
 			break;
-		case EPHY_DOWNLOAD_FAILED:
-			/* Translators: The text before the "|" is context to help you decide on
-			 * the correct translation. You MUST OMIT it in the translated string. */
-			text = Q_("download status|Failed");
+		case WEBKIT_DOWNLOAD_STATUS_ERROR:
+			text = C_("download status", "Failed");
 			break;
-		case EPHY_DOWNLOAD_DOWNLOADING:
-		case EPHY_DOWNLOAD_PAUSED:
+		case WEBKIT_DOWNLOAD_STATUS_CANCELLED:
+			text = C_("download status", "Cancelled");
+		case WEBKIT_DOWNLOAD_STATUS_STARTED:
 			if (percent == -1)
 			{
-				/* Translators: The text before the "|" is context to help you decide on
-				 * the correct translation. You MUST OMIT it in the translated string. */
-				text = Q_("download status|Unknown");
+				text = C_("download status", "Unknown");
 				percent = 0;
 			}
 			break;
@@ -720,7 +769,7 @@ downloader_view_build_ui (DownloaderView *dv)
 
 	ephy_dialog_construct (d,
 			       properties,
-			       ephy_file ("epiphany.glade"),
+			       ephy_file ("epiphany.ui"),
 			       "download_manager_dialog",
 			       NULL);
 
@@ -824,8 +873,8 @@ download_dialog_pause (DownloaderView *dv)
 	GtkTreeModel *model;
 	GtkTreeIter iter;
 	GValue val = {0, };
-	EphyDownload *download;
-	EphyDownloadState state;
+	WebKitDownload *download;
+	WebKitDownloadStatus status;
 
 	selection = gtk_tree_view_get_selection (GTK_TREE_VIEW(dv->priv->treeview));
 
@@ -834,16 +883,9 @@ download_dialog_pause (DownloaderView *dv)
 	gtk_tree_model_get_value (model, &iter, COL_DOWNLOAD_OBJECT, &val);
 	download = g_value_get_object (&val);
 
-	state = ephy_download_get_state (download);
+	status = webkit_download_get_status (download);
 
-	if (state == EPHY_DOWNLOAD_DOWNLOADING)
-	{
-		ephy_download_pause (download);
-	}
-	else if (state == EPHY_DOWNLOAD_PAUSED)
-	{
-		ephy_download_resume (download);
-	}
+	g_warning ("Pause/resume not implemented");
 
 	g_value_unset (&val);
 
@@ -851,7 +893,7 @@ download_dialog_pause (DownloaderView *dv)
 }
 
 void
-downloader_view_remove_download (DownloaderView *dv, EphyDownload *download)
+downloader_view_remove_download (DownloaderView *dv, WebKitDownload *download)
 {
 	GtkTreeRowReference *row_ref;
 	GtkTreePath *path = NULL;
@@ -888,9 +930,8 @@ downloader_view_remove_download (DownloaderView *dv, EphyDownload *download)
 	/* Removal */
 
 	gtk_list_store_remove (GTK_LIST_STORE (dv->priv->model), &iter2);
-	g_hash_table_remove (dv->priv->downloads_hash,
-			     download);
-	g_object_unref (download);
+	g_hash_table_remove (dv->priv->downloads_hash, download);
+	remove_download (download, NULL, dv);
 
 	/* Actual selection */
 
@@ -925,7 +966,7 @@ download_dialog_stop (DownloaderView *dv)
 	GList *selected = NULL;
 	GList *downloads = NULL;
 	GList *l = NULL;
-	EphyDownload *download;
+	WebKitDownload *download;
 
 	selection = gtk_tree_view_get_selection (GTK_TREE_VIEW(dv->priv->treeview));
 	model = gtk_tree_view_get_model (GTK_TREE_VIEW(dv->priv->treeview));
@@ -946,8 +987,7 @@ download_dialog_stop (DownloaderView *dv)
 	for (l = downloads; l; l = l->next)
 	{
 		if (!l->data) continue;
-		ephy_download_cancel ((EphyDownload*) l->data);
-		downloader_view_remove_download (dv, l->data);
+		webkit_download_cancel ((WebKitDownload*) l->data);
 		g_object_unref (l->data);
 	}
 	
