@@ -17,7 +17,6 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- *  $Id$
  */
 
 #include "config.h"
@@ -41,7 +40,6 @@ struct _EphyStatusbarPrivate
 
 	GtkWidget *caret_indicator;
 	GtkWidget *security_icon;
-	GtkWidget *progressbar;
 	GtkWidget *security_evbox;
 	GtkWidget *popups_manager_icon;
 	GtkWidget *popups_manager_evbox;
@@ -139,30 +137,6 @@ create_icon_frame (EphyStatusbar *statusbar,
 	*_icon = icon;
 }
 
-static void
-create_statusbar_progress (EphyStatusbar *s)
-{
-	EphyStatusbarPrivate *priv = s->priv;
-	GtkWidget *vbox;
-
-	vbox = gtk_vbox_new (FALSE, 0);
-	gtk_box_pack_end (GTK_BOX (priv->hbox), vbox, FALSE, FALSE, 0);
-
-	priv->progressbar = gtk_progress_bar_new ();
-	gtk_box_pack_start (GTK_BOX (vbox),
-			    GTK_WIDGET (priv->progressbar),
-		 	    TRUE, TRUE, 1);
-
-        /* We need to set the vertical size request to a small value here,
-         * because the progressbar's default size request is taller than the whole
-         * statusbar. Packing it with expand&fill in the vbox above will nevertheless
-         * make it use the greatest available height.
-         */
-	gtk_widget_set_size_request (priv->progressbar, -1, 10);
-
-	gtk_widget_show_all (vbox);
-}
-
 static void
 ephy_statusbar_init (EphyStatusbar *t)
 {
@@ -205,7 +179,6 @@ ephy_statusbar_init (EphyStatusbar *t)
 	/* don't show priv->popups_manager_evbox yet */
 
 	create_caret_indicator (t);
-	create_statusbar_progress (t);
 }
 
 /**
@@ -287,30 +260,6 @@ ephy_statusbar_set_popups_state (EphyStatusbar *statusbar,
 	}
 }
 
-/**
- * ephy_statusbar_set_progress:
- * @statusbar: a #EphyStatusbar
- * @progress: the progress as an integer between 0 and 100 per cent.
- * 
- * Sets the statusbar's progress.
- **/
-void
-ephy_statusbar_set_progress (EphyStatusbar *statusbar,
-			     int progress)
-{
-	gtk_progress_bar_set_fraction (GTK_PROGRESS_BAR (statusbar->priv->progressbar),
-				       (float) (progress) / 100.0);
-
-	if (progress < 100)
-	{
-		gtk_widget_show (statusbar->priv->progressbar);
-	}
-	else
-	{
-		gtk_widget_hide (statusbar->priv->progressbar);
-	}
-}
-
 static void
 sync_visibility (GtkWidget *widget,
 		 GParamSpec *pspec,
