@@ -16,7 +16,6 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- *  $Id$
  */
 
 #include "config.h"
@@ -24,6 +23,7 @@
 #include "ephy-embed-container.h"
 #include "ephy-embed-shell.h"
 #include "ephy-embed-single.h"
+#include "ephy-embed-utils.h"
 #include "ephy-shell.h"
 #include "ephy-embed-factory.h"
 #include "ephy-embed-persist.h"
@@ -107,7 +107,7 @@ window_cmd_file_print (GtkAction *action,
           (EPHY_EMBED_CONTAINER (window));
 	g_return_if_fail (EPHY_IS_EMBED (embed));
 
-	ephy_embed_print (embed);
+	webkit_web_view_execute_script (EPHY_GET_WEBKIT_WEB_VIEW_FROM_EMBED (embed), "print();");
 }
 
 void
@@ -115,15 +115,10 @@ window_cmd_file_send_to	(GtkAction *action,
 			 EphyWindow *window)
 {
 	EphyEmbed *embed;
-	char *handler, *command;
+	char *command, *subject, *body;
 	const char *location, *title;
-	GAppInfo *appinfo;
-	
-	if (eel_gconf_get_boolean ("/desktop/gnome/url-handlers/mailto/enabled") == FALSE)
-	{
-		/* FIXME: add some UI to inform the user? */
-		return;
-	}
+	GdkScreen *screen;
+	GError *error = NULL;
 
 	embed = ephy_embed_container_get_active_child 
           (EPHY_EMBED_CONTAINER (window));
@@ -132,20 +127,31 @@ window_cmd_file_send_to	(GtkAction *action,
 	location = ephy_embed_get_address (embed);
 	title = ephy_embed_get_title (embed);
 
-	/* FIXME: better use g_app_info_get_default_for_uri_scheme () when it is
-	 * implemented.
-	 */
-	handler = eel_gconf_get_string ("/desktop/gnome/url-handlers/mailto/command");
-	command = g_strconcat (handler, "mailto:",
-			       "?Subject=\"", title,
-			       "\"&Body=\"", location, "\"", NULL);
+	subject = g_uri_escape_string (title, NULL, TRUE);
+	body = g_uri_escape_string (location, NULL, TRUE);
+
+	command = g_strconcat ("mailto:",
+			       "?Subject=", subject,
+			       "&Body=", body, NULL);
+
+	g_free (subject);
+	g_free (body);
+
+	if (window)
+	{
+		screen = gtk_widget_get_screen (GTK_WIDGET (window));
+	}
+	else
+	{
+		screen = gdk_screen_get_default ();
+	}
 	
-	appinfo = g_app_info_create_from_commandline (command, NULL, 0, NULL);
-	ephy_file_launch_application (appinfo, NULL,
-				      gtk_get_current_event_time (),
-				      GTK_WIDGET (window));
+	if (!gtk_show_uri (screen, command, gtk_get_current_event_time(), &error)) 
+	{
+    		g_warning ("Unable to send link by email: %s\n", error->message);
+    		g_error_free (error);
+  	}
 
-	g_free (handler);
 	g_free (command);
 }
 
@@ -195,7 +201,7 @@ window_cmd_view_stop (GtkAction *action,
 
 	gtk_widget_grab_focus (GTK_WIDGET (embed));
 
-	ephy_embed_stop_load (embed);
+	webkit_web_view_stop_loading (EPHY_GET_WEBKIT_WEB_VIEW_FROM_EMBED (embed));
 }
 
 void
@@ -203,6 +209,7 @@ window_cmd_view_reload (GtkAction *action,
 		        EphyWindow *window)
 {
 	EphyEmbed *embed;
+	WebKitWebView *view;
 
 	embed = ephy_embed_container_get_active_child 
           (EPHY_EMBED_CONTAINER (window));
@@ -210,7 +217,11 @@ window_cmd_view_reload (GtkAction *action,
 
 	gtk_widget_grab_focus (GTK_WIDGET (embed));
 
-	ephy_embed_reload (embed, event_with_shift ());
+	view = EPHY_GET_WEBKIT_WEB_VIEW_FROM_EMBED (embed);
+	if (event_with_shift ())
+		webkit_web_view_reload_bypass_cache (view);
+	else
+		webkit_web_view_reload (view);
 }
 
 void
@@ -773,8 +784,6 @@ window_cmd_help_about (GtkAction *action,
 		   "51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA")
 	};
 
-	EphyEmbedShell *shell;
-	EphyEmbedSingle *single;
 	char *licence, *comments;
 	GKeyFile *key_file;
 	GError *error = NULL;
@@ -852,11 +861,8 @@ window_cmd_help_about (GtkAction *action,
 
 	g_key_file_free (key_file);
 
-	shell = ephy_embed_shell_get_default ();
-	single = EPHY_EMBED_SINGLE (ephy_embed_shell_get_embed_single (shell));
-
 	comments = g_strdup_printf (_("Lets you view web pages and find information on the internet.\n"
-				      "Powered by %s"), ephy_embed_single_get_backend_name (single) );
+				      "Powered by WebKit"));
 
 	licence = g_strjoin ("\n\n",
 			     _(licence_part[0]),
@@ -867,20 +873,20 @@ window_cmd_help_about (GtkAction *action,
 	gtk_show_about_dialog (GTK_WINDOW (window),
 			       "name", _("GNOME Web Browser"),
 			       "version", VERSION,
-			       "copyright", "Copyright © 2002-2004 Marco Pesenti Gritti\n"
-					    "Copyright © 2003-2009 The GNOME Web Browser Developers",
+			       "copyright", "Copyright © 2002–2004 Marco Pesenti Gritti\n"
+			                    "Copyright © 2003–2009 The GNOME Web Browser Developers",
 			       "artists", artists,
 			       "authors", authors,
 			       "comments", comments,
 			       "documenters", documenters,
-				/* Translators: This is a special message that shouldn't be translated
-				 * literally. It is used in the about box to give credits to
-				 * the translators.
-				 * Thus, you should translate it to your name and email address.
-				 * You should also include other translators who have contributed to
-				 * this translation; in that case, please write each of them on a separate
-				 * line seperated by newlines (\n).
-				 */
+			       /* Translators: This is a special message that shouldn't be translated
+			        * literally. It is used in the about box to give credits to
+			        * the translators.
+			        * Thus, you should translate it to your name and email address.
+			        * You should also include other translators who have contributed to
+			        * this translation; in that case, please write each of them on a separate
+			        * line seperated by newlines (\n).
+			        */
 			       "translator-credits", _("translator-credits"),
 			       "logo-icon-name", EPHY_STOCK_EPHY,
 			       "website", "http://www.gnome.org/projects/epiphany",
@@ -966,6 +972,30 @@ void window_cmd_tabs_move_right (GtkAction *action,
 	gtk_notebook_reorder_child (notebook, child, page + 1);
 }
 
+void
+window_cmd_tabs_detach  (GtkAction *action,
+			 EphyWindow *window)
+{
+        EphyEmbed *embed;
+        GtkNotebook *notebook;
+        EphyWindow *new_window;
+
+        notebook = GTK_NOTEBOOK (ephy_window_get_notebook (window));
+        if (gtk_notebook_get_n_pages (notebook) <= 1)
+                return;
+
+        embed = ephy_embed_container_get_active_child (EPHY_EMBED_CONTAINER (window));
+
+        g_object_ref_sink (embed);
+        gtk_notebook_remove_page (notebook, gtk_notebook_page_num (notebook, GTK_WIDGET (embed)));
+
+        new_window = ephy_window_new ();
+        ephy_embed_container_add_child (EPHY_EMBED_CONTAINER (new_window), embed, 0, FALSE);
+        g_object_unref (embed);
+
+        gtk_window_present (GTK_WINDOW (new_window));
+}
+
 void
 window_cmd_load_location (GtkAction *action,
 			  EphyWindow *window)
